@@ -37,7 +37,7 @@ class ConfigTypeTests(unittest.TestCase):
         MyString()
 
 
-class TypeTestHelper(object):
+class TypeTestHelper:
     def setUp(self):
         super(TypeTestHelper, self).setUp()
         self.type_instance = self.type
@@ -662,6 +662,12 @@ class DictTypeTests(TypeTestHelper, unittest.TestCase):
                                   {'foo': 'bar, baz',
                                    'bam': 'quux'})
 
+    def test_custom_separator(self):
+        self.type_instance = types.Dict(key_value_separator='=')
+        self.assertConvertedValue(' foo=bar, baz= 123 ',
+                                  {'foo': 'bar',
+                                   'baz': '123'})
+
     def test_dict_of_dicts(self):
         self.type_instance = types.Dict(
             types.Dict(types.String(), bounds=True)
